from django.conf.urls import url
from django.contrib.auth.decorators import permission_required
from kfet import views
from kfet import autocomplete

urlpatterns = [
    url(r'^$', views.home,
        name = 'kfet.home'),
    url(r'^login/genericteam$', views.login_genericteam,
        name = 'kfet.login.genericteam'),

    # -----
    # Account urls
    # -----

    # Account - General
    url(r'^accounts/$', views.account,
        name = 'kfet.account'),
    url(r'^accounts/is_validandfree$', views.account_is_validandfree_ajax,
        name = 'kfet.account.is_validandfree.ajax'),

    # Account - Create
    url(r'^accounts/new$', views.account_create,
        name = 'kfet.account.create'),
    url(r'^accounts/new/user/(?P<username>.+)$', views.account_create_ajax,
        name = 'kfet.account.create.fromuser'),
    url(r'^accounts/new/clipper/(?P<login_clipper>.+)$', views.account_create_ajax,
        name = 'kfet.account.create.fromclipper'),
    url(r'^accounts/new/empty$', views.account_create_ajax,
        name = 'kfet.account.create.empty'),
    url(r'^autocomplete/account_new$', autocomplete.account_create,
        name = 'kfet.account.create.autocomplete'),

    # Account - Read
    url(r'^accounts/(?P<trigramme>.{3})$', views.account_read,
        name = 'kfet.account.read'),

    # Account - Update
    url(r'^accounts/(?P<trigramme>.{3})/edit$', views.account_update,
        name = 'kfet.account.update'),

    # -----
    # Checkout urls
    # -----

    # Checkout - General
    url('^checkouts/$',
        permission_required('kfet.is_team')(views.CheckoutList.as_view()),
        name = 'kfet.checkout'),
    # Checkout - Create
    url('^checkouts/new$',
        permission_required('kfet.is_team')(views.CheckoutCreate.as_view()),
        name = 'kfet.checkout.create'),
    # Checkout - Read
    url('^checkouts/(?P<pk>\d+)$',
        permission_required('kfet.is_team')(views.CheckoutRead.as_view()),
        name = 'kfet.checkout.read'),
    # Checkout - Update
    url('^checkouts/(?P<pk>\d+)/edit$',
        permission_required('kfet.is_team')(views.CheckoutUpdate.as_view()),
        name = 'kfet.checkout.update'),

    ### Checkout Statements urls

    # Checkout Statement - General
    url('^checkouts/statements/$',
        permission_required('kfet.is_team')(views.CheckoutStatementList.as_view()),
        name = 'kfet.checkoutstatement'),
    # Checkout Statement - Create
    url('^checkouts/(?P<pk_checkout>\d+)/statements/add',
        permission_required('kfet.is_team')(views.CheckoutStatementCreate.as_view()),
        name = 'kfet.checkoutstatement.create'),

    # -----
    # Article urls
    # -----

    # Article - General
    url('^articles/$',
        permission_required('kfet.is_team')(views.ArticleList.as_view()),
        name = 'kfet.article'),
    # Article - Create
    url('^articles/new$',
        permission_required('kfet.is_team')(views.ArticleCreate.as_view()),
        name = 'kfet.article.create'),
    # Article - Read
    url('^articles/(?P<pk>\d+)$',
        permission_required('kfet.is_team')(views.ArticleRead.as_view()),
        name = 'kfet.article.read'),
    # Article - Update
    url('^articles/(?P<pk>\d+)/edit$',
        permission_required('kfet.is_team')(views.ArticleUpdate.as_view()),
        name = 'kfet.article.update'),

    # -----
    # K-Psul urls
    # -----

    url('^k-psul/$', views.kpsul, name = 'kfet.kpsul'),
    url('^k-psul/account_data$', views.kpsul_account_data,
        name = 'kfet.kpsul.account_data'),
    url('^k-psul/checkout_data$', views.kpsul_checkout_data,
        name = 'kfet.kpsul.checkout_data'),
    url('^k-psul/perform_operations$', views.kpsul_perform_operations,
        name = 'kfet.kpsul.perform_operations'),
    url('^k-psul/cancel_operations$', views.kpsul_cancel_operations,
        name = 'kfet.kpsul.cancel_operations'),
    url('^k-psul/history$', views.kpsul_history,
        name = 'kfet.kpsul.history'),
    url('^k-psul/articles_data', views.kpsul_articles_data,
        name = 'kfet.kpsul.articles_data')
]
